tennyson.py
===========

Collection of helpful functions by Tennyson T Bardwell

Important Notes
---------------

- has personal info committed

Development
-----------

### Helpful Commands ###

```bash
sudo pip install .     # install package
python3 setup.py test  # test package
python3 setup.py build # builds package
python3 setup.py sdist bdist_wheel && twine upload dist/* # distributes package
```

### TODO ###

- graceful handling of email errors if no network

